==> openlitespeed-1.4.47.src.tgz: openlitespeed-1.4.47/src/http/hiohandlerfactory.cpp <==
/*****************************************************************************
*    Open LiteSpeed is an open source HTTP server.                           *
*    Copyright (C) 2013 - 2018  LiteSpeed Technologies, Inc.                 *
*                                                                            *
*    This program is free software: you can redistribute it and/or modify    *
*    it under the terms of the GNU General Public License as published by    *
*    the Free Software Foundation, either version 3 of the License, or       *
*    (at your option) any later version.                                     *
*                                                                            *
*    This program is distributed in the hope that it will be useful,         *
*    but WITHOUT ANY WARRANTY; without even the implied warranty of          *
*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the            *
*    GNU General Public License for more details.                            *
*                                                                            *
*    You should have received a copy of the GNU General Public License       *
*    along with this program. If not, see http://www.gnu.org/licenses/.      *
*****************************************************************************/

#include "hiohandlerfactory.h"

#include <http/httpresourcemanager.h>
#include <http/httpsession.h>
#include <spdy/h2connection.h>
#include <spdy/spdyconnection.h>

HioHandler *HioHandlerFactory::getHioHandler(HiosProtocol proto)
{
    HioHandler *pHioHandler;
    switch (proto)
    {
    case HIOS_PROTO_HTTP:
        pHioHandler = HttpResourceManager::getInstance().getHttpSession();
        return pHioHandler;
    case HIOS_PROTO_HTTP2:
        pHioHandler = H2Connection::get();
        break;
    default:
        pHioHandler = SpdyConnection::get(proto);
        break;
    }

    return pHioHandler;
}

==> openlitespeed-1.5.0.src.tgz: openlitespeed-1.5.0/src/http/hiohandlerfactory.cpp <==
/*****************************************************************************
*    Open LiteSpeed is an open source HTTP server.                           *
*    Copyright (C) 2013 - 2018  LiteSpeed Technologies, Inc.                 *
*                                                                            *
*    This program is free software: you can redistribute it and/or modify    *
*    it under the terms of the GNU General Public License as published by    *
*    the Free Software Foundation, either version 3 of the License, or       *
*    (at your option) any later version.                                     *
*                                                                            *
*    This program is distributed in the hope that it will be useful,         *
*    but WITHOUT ANY WARRANTY; without even the implied warranty of          *
*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the            *
*    GNU General Public License for more details.                            *
*                                                                            *
*    You should have received a copy of the GNU General Public License       *
*    along with this program. If not, see http://www.gnu.org/licenses/.      *
*****************************************************************************/

#include "hiohandlerfactory.h"

#include <http/httpresourcemanager.h>
#include <http/httpsession.h>
#include <spdy/h2connection.h>
#include <spdy/spdyconnection.h>

HioHandler *HioHandlerFactory::getHioHandler(HiosProtocol proto)
{
    HioHandler *pHioHandler;
    switch (proto)
    {
    case HIOS_PROTO_HTTP:
        pHioHandler = HttpResourceManager::getInstance().getConnection();
        return pHioHandler;
    case HIOS_PROTO_HTTP2:
        pHioHandler = H2Connection::get();
        break;
    default:
        pHioHandler = SpdyConnection::get(proto);
        break;
    }

    return pHioHandler;
}
